# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CouponFragment


class CreateCoupon(BaseModel):
    create_one_coupon: "CreateCouponCreateOneCoupon" = Field(alias="createOneCoupon")


class CreateCouponCreateOneCoupon(CouponFragment):
    pass


CreateCoupon.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class TransferSubscriptionToResource(BaseModel):
    transfer_subscription_to_resource: "TransferSubscriptionToResourceTransferSubscriptionToResource" = Field(
        alias="transferSubscriptionToResource"
    )


class TransferSubscriptionToResourceTransferSubscriptionToResource(
    SlimSubscriptionFragment
):
    pass


TransferSubscriptionToResource.model_rebuild()
